#include <gtk/gtk.h>
#include <gtk/gtkx.h>
#include "gddcalc.h"

void colorWidgets() {

	GdkColor color;
	color.red = 0x3333;
	color.green = 0xffff;
	color.blue = 0xcccc;
	gtk_widget_modify_bg(window, GTK_STATE_NORMAL, &color);           // light green
	gtk_widget_modify_bg(locale, GTK_STATE_NORMAL, &color);
	gtk_widget_modify_bg(quit, GTK_STATE_NORMAL, &color);
	gtk_widget_modify_bg(oneday, GTK_STATE_NORMAL, &color);
	gtk_widget_modify_bg(months, GTK_STATE_NORMAL, &color);
	gtk_widget_modify_bg(testoneinstant, GTK_STATE_NORMAL, &color);
	gtk_widget_modify_bg(testoneday, GTK_STATE_NORMAL, &color);
	gtk_widget_modify_bg(testgrowingseason, GTK_STATE_NORMAL, &color);
	gtk_widget_modify_bg(tutorial, GTK_STATE_NORMAL, &color);
	gtk_widget_modify_bg(about, GTK_STATE_NORMAL, &color);
	gtk_widget_modify_bg(error_frame, GTK_STATE_NORMAL, &color);
	
	
	color.red = 0x3333;
	color.green = 0xeeee;
	color.blue = 0xcccc;
	gtk_widget_modify_bg(t1_frame, GTK_STATE_NORMAL, &color);        // green
	gtk_widget_modify_bg(t2_frame, GTK_STATE_NORMAL, &color);
	gtk_widget_modify_bg(t3_frame, GTK_STATE_NORMAL, &color);
	gtk_widget_modify_bg(locale_frame, GTK_STATE_NORMAL, &color);

	color.red = 0xeeee;
	color.green = 0x3333;
	color.blue = 0xaaaa;
	gtk_widget_modify_bg(locale_topband, GTK_STATE_NORMAL, &color);  // red
	gtk_widget_modify_bg(t1_topband, GTK_STATE_NORMAL, &color);
	gtk_widget_modify_bg(t2_topband, GTK_STATE_NORMAL, &color);
	gtk_widget_modify_bg(t3_topband, GTK_STATE_NORMAL, &color);
	gtk_widget_modify_bg(error_topband, GTK_STATE_NORMAL, &color);	
}
