/* Called from gddcalc.c to build the widgets that appear in the dialog
 * boxes. The quoted names below are those of entities described in the
 * Glade xml file. Here, builder transforms them into gtk widgets. 
 * The names of the widgets in the left-hand column are those they have
 * in the C code. Note that they are arbitrary; they need not be the same
 * as those in the xml file.
 */

#include <gtk/gtk.h>
#include <gtk/gtkx.h>
#include "gddcalc.h"

void buildWidgets(GtkBuilder *builder) {

	fixed0 = GTK_WIDGET(gtk_builder_get_object(builder, "fixed0"));
	menu1 = GTK_WIDGET(gtk_builder_get_object(builder, "menu1"));
	startlogging = GTK_WIDGET(gtk_builder_get_object(builder, "startlogging"));
	savelog = GTK_WIDGET(gtk_builder_get_object(builder, "savelog"));
	locale = GTK_WIDGET(gtk_builder_get_object(builder, "locale"));
	quit = GTK_WIDGET(gtk_builder_get_object(builder, "quit"));
	oneday = GTK_WIDGET(gtk_builder_get_object(builder, "oneday"));
	months = GTK_WIDGET(gtk_builder_get_object(builder, "months"));
	testoneinstant = GTK_WIDGET(gtk_builder_get_object(builder, "testoneinstant"));
	testoneday = GTK_WIDGET(gtk_builder_get_object(builder, "testoneday"));
	testgrowingseason = GTK_WIDGET(gtk_builder_get_object(builder, "testgrowingseason"));
	tutorial = GTK_WIDGET(gtk_builder_get_object(builder, "tutorial"));
	about = GTK_WIDGET(gtk_builder_get_object(builder, "about"));
// -----------------------------
	t1_frame = GTK_WIDGET(gtk_builder_get_object(builder, "t1_frame"));
	t1_fixed = GTK_WIDGET(gtk_builder_get_object(builder, "t1_fixed"));
	t1_entry1 = GTK_WIDGET(gtk_builder_get_object(builder, "t1_entry1"));
	t1_entry2 = GTK_WIDGET(gtk_builder_get_object(builder, "t1_entry2"));
	t1_entry3 = GTK_WIDGET(gtk_builder_get_object(builder, "t1_entry3"));
	t1_entry4 = GTK_WIDGET(gtk_builder_get_object(builder, "t1_entry4"));
	t1_entry5 = GTK_WIDGET(gtk_builder_get_object(builder, "t1_entry5"));
	t1_entry6 = GTK_WIDGET(gtk_builder_get_object(builder, "t1_entry6"));
	t1_entry7 = GTK_WIDGET(gtk_builder_get_object(builder, "t1_entry7"));
	t1_entry8 = GTK_WIDGET(gtk_builder_get_object(builder, "t1_entry8"));
	t1_entry9 = GTK_WIDGET(gtk_builder_get_object(builder, "t1_entry9"));
	t1_entry10 = GTK_WIDGET(gtk_builder_get_object(builder, "t1_entry10"));
	t1_entry11 = GTK_WIDGET(gtk_builder_get_object(builder, "t1_entry11"));
	t1_entry12 = GTK_WIDGET(gtk_builder_get_object(builder, "t1_entry12"));
	t1_calculate = GTK_WIDGET(gtk_builder_get_object(builder, "t1_calculate"));
	t1_close = GTK_WIDGET(gtk_builder_get_object(builder, "t1_close"));
	t1_topband = GTK_WIDGET(gtk_builder_get_object(builder, "t1_topband"));
	t1_explanation = GTK_WIDGET(gtk_builder_get_object(builder, "t1_explanation"));
// ------------------------------
	t2_calculate = GTK_WIDGET(gtk_builder_get_object(builder, "t2_calculate"));
	t2_close = GTK_WIDGET(gtk_builder_get_object(builder, "t2_close"));
	t2_frame = GTK_WIDGET(gtk_builder_get_object(builder, "t2_frame"));
	t2_fixed = GTK_WIDGET(gtk_builder_get_object(builder, "t2_fixed"));
	t2_frame1 = GTK_WIDGET(gtk_builder_get_object(builder, "t2_frame1"));
	t2_fixed1 = GTK_WIDGET(gtk_builder_get_object(builder, "t2_fixed1"));
	t2_entry1 = GTK_WIDGET(gtk_builder_get_object(builder, "t2_entry1"));
	t2_entry2 = GTK_WIDGET(gtk_builder_get_object(builder, "t2_entry2"));
	t2_entry3 = GTK_WIDGET(gtk_builder_get_object(builder, "t2_entry3"));
	t2_topband = GTK_WIDGET(gtk_builder_get_object(builder, "t2_topband"));
// -------------------------------
	t3_frame = GTK_WIDGET(gtk_builder_get_object(builder, "t3_frame"));
	t3_fixed = GTK_WIDGET(gtk_builder_get_object(builder, "t3_fixed"));
	t3_box = GTK_WIDGET(gtk_builder_get_object(builder, "t3_box"));
	t3_grid = GTK_WIDGET(gtk_builder_get_object(builder, "t3_grid"));
	t3_calculate = GTK_WIDGET(gtk_builder_get_object(builder, "t3_calculate"));
	t3_close = GTK_WIDGET(gtk_builder_get_object(builder, "t3_close"));
	t3_entry1 = GTK_WIDGET(gtk_builder_get_object(builder, "t3_entry1"));
	t3_entry2 = GTK_WIDGET(gtk_builder_get_object(builder, "t3_entry2"));
	t3_entry3 = GTK_WIDGET(gtk_builder_get_object(builder, "t3_entry3"));
	t3_entry4 = GTK_WIDGET(gtk_builder_get_object(builder, "t3_entry4"));
	t3_entry5 = GTK_WIDGET(gtk_builder_get_object(builder, "t3_entry5"));
	t3_entry6 = GTK_WIDGET(gtk_builder_get_object(builder, "t3_entry6"));
	t3_entry7 = GTK_WIDGET(gtk_builder_get_object(builder, "t3_entry7"));
	t3_entry8 = GTK_WIDGET(gtk_builder_get_object(builder, "t3_entry8"));
	t3_topband = GTK_WIDGET(gtk_builder_get_object(builder, "t3_topband"));
// -------------------------------
	error_frame = GTK_WIDGET(gtk_builder_get_object(builder, "error_frame"));
	error_fixed = GTK_WIDGET(gtk_builder_get_object(builder, "error_fixed"));
	error_topband = GTK_WIDGET(gtk_builder_get_object(builder, "error_topband"));
	error_box = GTK_WIDGET(gtk_builder_get_object(builder, "error_box"));
	error_grid = GTK_WIDGET(gtk_builder_get_object(builder, "error_grid"));
	error_close = GTK_WIDGET(gtk_builder_get_object(builder, "error_close"));
// ------------------------------------------------------------------------------
	c1_window = GTK_WIDGET(gtk_builder_get_object(builder, "c1_window"));
	c2_window = GTK_WIDGET(gtk_builder_get_object(builder, "c2_window"));
// ------------------------------------------------------------------------------
	locale_frame = GTK_WIDGET(gtk_builder_get_object(builder, "locale_frame"));
	locale_fixed = GTK_WIDGET(gtk_builder_get_object(builder, "locale_fixed"));
	locale_entry_lat = GTK_WIDGET(gtk_builder_get_object(builder, "locale_entry_lat"));
	locale_entry_lon = GTK_WIDGET(gtk_builder_get_object(builder, "locale_entry_lon"));
	locale_entry_elev = GTK_WIDGET(gtk_builder_get_object(builder, "locale_entry_elev"));
	locale_entry_aspect = GTK_WIDGET(gtk_builder_get_object(builder, "locale_entry_aspect"));
	locale_entry_tilt = GTK_WIDGET(gtk_builder_get_object(builder, "locale_entry_tilt"));
	locale_clear = GTK_WIDGET(gtk_builder_get_object(builder, "locale_clear"));
	locale_save = GTK_WIDGET(gtk_builder_get_object(builder, "locale_save"));
	locale_close = GTK_WIDGET(gtk_builder_get_object(builder, "locale_close"));
	locale_topband = GTK_WIDGET(gtk_builder_get_object(builder, "locale_topband"));
// -------------------------------------------------------------------------------
	tutorial_frame = GTK_WIDGET(gtk_builder_get_object(builder, "tutorial_frame"));
	tutorial_fixed = GTK_WIDGET(gtk_builder_get_object(builder, "tutorial_fixed"));
	tutorial_dismiss = GTK_WIDGET(gtk_builder_get_object(builder, "tutorial_dismiss"));
// -------------------------------------------------------------------------------
	about_frame = GTK_WIDGET(gtk_builder_get_object(builder, "about_frame"));
	about_fixed = GTK_WIDGET(gtk_builder_get_object(builder, "about_fixed"));
	about_dismiss = GTK_WIDGET(gtk_builder_get_object(builder, "about_dismiss"));
}
