entry {
	min-height: 28px;
	border: 1px solid;
	border-radius: 4px;
	color: #222222;                                             /* color of text */
	border-color: #ffffff;                                      /* outer rim of border */
	background-color: #fcfcfc;                                  /* interior color */
	box-shadow: inset 0px 0px 2px 2px rgba(30, 200, 100, 0.9);  /* inset shading */
}
button { 
	min-height: 24px;
	min-width: 22px;
	padding: 1px 2px;
	border: 2px solid;
	border-radius: 6px;
	transition: all 200ms cubic-bezier(0.25, 0.46, 0.45, 0.94);
	color: #222222;
	outline-color: rgba(00, 00, 00, 0.99);
	border-top-color: shade(#cecece, 0.8);
	border-right-color: shade(#cecece, 0.72);
	border-left-color: shade(#cecece, 0.72);
	border-bottom-color: shade(#cecece, 0.7);
	background-image: linear-gradient(to bottom, shade(shade(#aaaaaa, 1.02), 0.8), shade(shade(#eeeeee, 1.02), 1.2));
	box-shadow: inset 0 1px rgba(200, 200, 200, 0.9);
}
button:disabled {
    color: #929595;
    border-color: #e1ddda;
    background-color: #faf9f8;
    box-shadow: none;
    text-shadow: none;
    -gtk-icon-shadow: none;
}
