/* Fills the entry boxes of the growing season test display when gddcalc
 * gdd hides it, so that if the display is shown again it will not contain
 * the results of a previous call to t3_Populate.
 */

#include <gtk/gtk.h>
#include "gddcalc.h"
#include "solpos.h"

void t3_Depopulate() {

	char bfr[6];
	strcpy(bfr, "\0");

	gtk_entry_set_text (GTK_ENTRY (t3_entry1), (gchar*) bfr);
	gtk_entry_set_text (GTK_ENTRY (t3_entry2), (gchar*) bfr);
	gtk_entry_set_text (GTK_ENTRY (t3_entry3), (gchar*) bfr);
	gtk_entry_set_text (GTK_ENTRY (t3_entry4), (gchar*) bfr);
	gtk_entry_set_text (GTK_ENTRY (t3_entry5), (gchar*) bfr);
	gtk_entry_set_text (GTK_ENTRY (t3_entry6), (gchar*) bfr);
	gtk_entry_set_text (GTK_ENTRY (t3_entry7), (gchar*) bfr);
	gtk_entry_set_text (GTK_ENTRY (t3_entry8), (gchar*) bfr);
	gtk_widget_set_sensitive(GTK_WIDGET(t3_calculate), TRUE);
}
