#ifndef MANYDAYS_H
#define MANYDAYS_H

#include <gtk/gtk.h>

/* Struct definition */
typedef struct {

/* grid 1 (input) entries */
	GtkWidget	*entry_lat;
	GtkWidget	*entry_lon;
	GtkWidget	*entry_elev;
	GtkWidget	*entry_aspect;
	GtkWidget	*entry_tilt;
	GtkWidget	*entry_startday;
	GtkWidget	*entry_stopday;
	GtkWidget	*entry_year;
	GtkComboBoxText	*cbtxt_startmonth;
	GtkComboBoxText	*cbtxt_stopmonth;
	GtkWidget	*lbl_month_error;

/* grid 2 (output) entries */
	GtkWidget	*entry_month;
	GtkWidget	*entry_ndays;
	GtkWidget	*entry_mthirr;
	GtkWidget	*entry_mthgdd;
	GtkWidget	*entry_cumirr;
	GtkWidget	*entry_cumgdd;

/* grid 3 buttons */
	GtkWidget	*btn_start;
	GtkWidget	*btn_continue;
	GtkWidget	*btn_close;
	
} c2_widgets;

/* Prototypes that use c2widgets */
int c2_CheckEntries(c2_widgets *w);
void c2_ShowResult(c2_widgets *w);

#endif
