/* Fills the entry boxes of the "one instant in Atlanta" display when
 * gdd hides it, so that if the display is shown again it will not contain
 * the results of a previous call to t1_Populate.
 */

#include <gtk/gtk.h>
#include "gddcalc.h"
#include "solpos.h"

void t1_Depopulate() {

	char bfr[8];
	strcpy(bfr, "");

	gtk_entry_set_text (GTK_ENTRY (t1_entry1), (gchar*) bfr);
	gtk_entry_set_text (GTK_ENTRY (t1_entry2), (gchar*) bfr);
	gtk_entry_set_text (GTK_ENTRY (t1_entry3), (gchar*) bfr);
	gtk_entry_set_text (GTK_ENTRY (t1_entry4), (gchar*) bfr);
	gtk_entry_set_text (GTK_ENTRY (t1_entry5), (gchar*) bfr);
	gtk_entry_set_text (GTK_ENTRY (t1_entry6), (gchar*) bfr);
	gtk_entry_set_text (GTK_ENTRY (t1_entry7), (gchar*) bfr);
	gtk_entry_set_text (GTK_ENTRY (t1_entry8), (gchar*) bfr);
	gtk_entry_set_text (GTK_ENTRY (t1_entry9), (gchar*) bfr);
	gtk_entry_set_text (GTK_ENTRY (t1_entry10), (gchar*) bfr);
	gtk_entry_set_text (GTK_ENTRY (t1_entry11), (gchar*) bfr);
	gtk_entry_set_text (GTK_ENTRY (t1_entry12), (gchar*) bfr);
	gtk_widget_set_sensitive(GTK_WIDGET(t1_calculate), TRUE);
}
