/* t2_Depopulate
 * Called by gddcalc when "one day" ("test" in the window header) is clicked.
 */

#include <gtk/gtk.h>
#include "gddcalc.h"

void t2_Depopulate() {
	char bfr[6];

	strcpy(bfr, "\0");

	gtk_entry_set_text (GTK_ENTRY (t2_entry1), (gchar*) bfr);
	gtk_entry_set_text (GTK_ENTRY (t2_entry2), (gchar*) bfr);
	gtk_entry_set_text (GTK_ENTRY (t2_entry3), (gchar*) bfr);
	gtk_widget_set_sensitive(GTK_WIDGET(t2_calculate), TRUE);
}
