#include <gtk/gtk.h>
#include <gtk/gtkx.h>
#include "gddcalc.h"

int getMonthNumber(char *);                           // prototype

int readCBTAT(GtkComboBoxText *cbt) {
	gchar* bfr = NULL;
	bfr = gtk_combo_box_text_get_active_text(GTK_COMBO_BOX_TEXT(cbt));
	return getMonthNumber(bfr);
}
