/* getMonthsGDD.
 * Calculates the increment of GDD (growing degree days) that
 * corresponds to the amount of radiation falling on a (possibly
 * tilted) square meter during one month. month lies in [1, 12].
 */
 
#include "gddcalc.h"

float northGDD(float, int);                     // prototype
float southGDD(float, int);                     // prototype

/* The inputs to this function are (1) accumulated irradiance
 * and (2) the month for which that irradiance was calculated.
 */

float getMonthsGDD(float irr, int month) {

	float gdd;
	if (northsouth == 1)
		gdd = northGDD(irr, month);
	else if (northsouth == 2)   
		gdd = southGDD(irr, month);

	return gdd;
}
