#include <string.h>
#include "gddcalc.h"

int getMonthNumber(char *bfr) {
	int k;
	char *mthname[] = {"January", "February", "March", "April", "May", 
	"June", "July", "August", "September", "October", "November",
	"December"};
	for (k = 0; k < 12; k++) {
		if (strcmp(bfr, mthname[k]) == 0) break;
	}
	return k + 1;
}
