#ifndef ONEDAY_H
#define ONEDAY_H

#include <gtk/gtk.h>

/* Struct definition */
typedef struct {

/* grid 1 (input) entries */
	GtkWidget *c1_entry1;
	GtkWidget *c1_entry2;
	GtkWidget *c1_entry3;
	GtkWidget *c1_entry4;
	GtkWidget *c1_entry5;
	GtkWidget *c1_entry6;
	GtkComboBoxText *c1_cbtxt_month;
	GtkWidget *c1_entry8;

/* grid 2 (output) entries */
	GtkWidget *c1_entry9;
	GtkWidget *c1_entry10;
	GtkWidget *c1_entry11;
	GtkWidget *c1_entry12;

/* grid 3 buttons */
	GtkWidget *c1_calculate;
	GtkWidget *c1_dismiss;

} c1_widgets;

/* Prototypes that use c1_widgets */
int c1_CheckEntries(c1_widgets *w);
void c1_ShowResult(c1_widgets *w);

#endif
